import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_contact/ocg_contact.dart';

///
/// Event
///
abstract class ContactListEvent {}

class ContactListRefreshEvent extends ContactListEvent {
  ContactListRefreshEvent();
}

///
/// State
///
abstract class ContactListState {}

class ContactListIdleState extends ContactListState {}

class ContactListLoadingState extends ContactListState {}

class ContactListLoadedState extends ContactListState {
  final List<Contact> contacts;

  ContactListLoadedState(this.contacts);
}

class ContactListErrorState extends ContactListState {
  final String error;

  ContactListErrorState(this.error);
}

class ContactListBloc extends Bloc<ContactListEvent, ContactListState> {
  final ContactRepository contactRepository;

  ContactListBloc(this.contactRepository) : super(ContactListIdleState());
  @override
  Stream<ContactListState> mapEventToState(ContactListEvent event) async* {
    if (event is ContactListRefreshEvent) {
      yield ContactListLoadingState();
      AppResponse<List<Contact>> contactResposne =
          await contactRepository.fetchPhoneContacts();
      if (contactResposne.isSuccess) {
        yield ContactListLoadedState(contactResposne.data);
      } else {
        yield ContactListErrorState(contactResposne.error);
      }
    }
  }
}
